@@ -1,21 +1,10 @@
-from warnings import warn
-
+import geopandas
 import numpy
+import pandas
+import shapely
 from libpysal import cg
-from libpysal.common import requires
 from rtree import Rtree
-
-try:
-    import geopandas
-    import pandas
-    import shapely
-    from shapely.geometry import LineString
-except ImportError:
-    warn(
-        "geopandas/shapely not available. Some functionality will be disabled.",
-        UserWarning,
-        stacklevel=1,
-    )
+from shapely.geometry import LineString
 
 
 def compute_length(v0, v1):
@@ -75,7 +64,7 @@ def get_neighbor_distances(ntw, v0, link):
     >>> ntw = spaghetti.Network(examples.get_path("streets.shp"))
     >>> neighs = spaghetti.util.get_neighbor_distances(ntw, 0, ntw.arc_lengths)
     >>> numpy.round(neighs[1], 10)
-    102.6235345344
+    np.float64(102.6235345344)
 
     """
 
@@ -118,9 +107,9 @@ def generatetree(pred):
     >>> distance, pred = spaghetti.util.dijkstra(ntw, 0)
     >>> tree = spaghetti.util.generatetree(pred)
     >>> tree[3]
-    [23, 22, 20, 19, 170, 2, 0]
+    [np.int64(23), np.int64(22), np.int64(20), np.int64(19), np.int64(170), np.int64(2), np.int64(0)]
 
-    """
+    """  # noqa: E501
 
     # instantiate tree lookup
     tree = {}
@@ -192,7 +181,7 @@ def dijkstra(ntw, v0, initial_dist=numpy.inf):
     >>> round(distance[196], 4)
     5505.6682
     >>> pred[196]
-    133
+    np.int64(133)
 
     """
 
@@ -280,7 +269,7 @@ def dijkstra_mp(ntw_vertex):
     >>> round(distance[196], 4)
     5505.6682
     >>> pred[196]
-    133
+    np.int64(133)
 
     """
 
@@ -316,7 +305,7 @@ def squared_distance_point_link(point, link):
     >>> import spaghetti
     >>> point, link = (1,1), ((0,0), (2,0))
     >>> spaghetti.util.squared_distance_point_link(point, link)
-    (1.0, array([1., 0.]))
+    (np.float64(1.0), array([1., 0.]))
 
     """
 
@@ -654,7 +643,6 @@ def build_chains(space_h, space_v, exterior, bounds, h=True):
     return chains
 
 
-@requires("geopandas", "shapely")
 def _points_as_gdf(net, vertices, vertices_for_arcs, pp_name, snapped, id_col=None):
     """Internal function for returning a point ``geopandas.GeoDataFrame``
     called from within ``spaghetti.element_as_gdf()``.
@@ -686,8 +674,7 @@ def _points_as_gdf(net, vertices, vertices_for_arcs, pp_name, snapped, id_col=No
     Notes
     -----
 
-    1. See ``spaghetti.element_as_gdf()`` for description of arguments.
-    2. This function requires ``geopandas``.
+    See ``spaghetti.element_as_gdf()`` for description of arguments.
 
     """
 
@@ -736,7 +723,6 @@ def _points_as_gdf(net, vertices, vertices_for_arcs, pp_name, snapped, id_col=No
     return points
 
 
-@requires("geopandas", "shapely")
 def _arcs_as_gdf(net, points, id_col=None):
     """Internal function for returning an arc ``geopandas.GeoDataFrame``
     called from within ``spaghetti.element_as_gdf()``.
@@ -751,8 +737,7 @@ def _arcs_as_gdf(net, points, id_col=None):
     Notes
     -----
 
-    1. See ``spaghetti.element_as_gdf()`` for description of arguments.
-    2. This function requires ``geopandas``.
+    See ``spaghetti.element_as_gdf()`` for description of arguments.
 
     """
 
@@ -776,7 +761,6 @@ def _arcs_as_gdf(net, points, id_col=None):
     return arcs
 
 
-@requires("geopandas", "shapely")
 def _routes_as_gdf(paths, id_col):
     """Internal function for returning a shortest paths
     ``geopandas.GeoDataFrame`` called from within
@@ -793,8 +777,7 @@ def _routes_as_gdf(paths, id_col):
     Notes
     -----
 
-    1. See ``spaghetti.element_as_gdf()`` for description of arguments.
-    2. This function requires ``geopandas``.
+    See ``spaghetti.element_as_gdf()`` for description of arguments.
 
     """
 
